CurrentThreadClassLoadingStrategy (py4j-java 0.10.0 API)
Date: 2016-04-18

py4j.reflection

## Class CurrentThreadClassLoadingStrategy

- java.lang.Object
- - py4j.reflection.CurrentThreadClassLoadingStrategy

- All Implemented Interfaces:
    ClassLoadingStrategy

      public class CurrentThreadClassLoadingStrategy
      extends java.lang.Object
      implements ClassLoadingStrategy

  This class loading strategy uses the current thread's ClassLoader to load a class from a fully qualified name.

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `CurrentThreadClassLoadingStrategy()`

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `java.lang.Class<?>` | `classForName(java.lang.String className)`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Constructor Detail

    - #### CurrentThreadClassLoadingStrategy

          public CurrentThreadClassLoadingStrategy()

  - ### Method Detail

    - #### classForName

          public java.lang.Class<?> classForName(java.lang.String className)
                                          throws java.lang.ClassNotFoundException

      Specified by:
        `classForName` in interface `ClassLoadingStrategy`
      Throws:
        `java.lang.ClassNotFoundException`